<?php

defined( 'ABSPATH' ) or die;

$GLOBALS['processed_terms'] = array();
$GLOBALS['processed_posts'] = array();

require_once ABSPATH . 'wp-admin/includes/post.php';
require_once ABSPATH . 'wp-admin/includes/taxonomy.php';
require_once ABSPATH . 'wp-admin/includes/image.php';

/**
 * Add an Import Action, this data is stored for processing after import is done.
 *
 * Each action is sent as an Ajax request and is handled by themify-ajax.php file
 */ 
function themify_add_import_action( $action = '', $data = array() ) {
	global $import_actions;

	if ( ! isset( $import_actions[ $action ] ) ) {
		$import_actions[ $action ] = array();
	}

	$import_actions[ $action ][] = $data;
}

function themify_import_post( $post ) {
	global $processed_posts, $processed_terms;

	if ( ! post_type_exists( $post['post_type'] ) ) {
		return;
	}

	/* Menu items don't have reliable post_title, skip the post_exists check */
	if( $post['post_type'] !== 'nav_menu_item' ) {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
		if ( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
			$processed_posts[ intval( $post['ID'] ) ] = intval( $post_exists );
			return;
		}
	}

	if( $post['post_type'] == 'nav_menu_item' ) {
		if( ! isset( $post['tax_input']['nav_menu'] ) || ! term_exists( $post['tax_input']['nav_menu'], 'nav_menu' ) ) {
			return;
		}
		$_menu_item_type = $post['meta_input']['_menu_item_type'];
		$_menu_item_object_id = $post['meta_input']['_menu_item_object_id'];

		if ( 'taxonomy' == $_menu_item_type && isset( $processed_terms[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_terms[ intval( $_menu_item_object_id ) ];
		} else if ( 'post_type' == $_menu_item_type && isset( $processed_posts[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_posts[ intval( $_menu_item_object_id ) ];
		} else if ( 'custom' != $_menu_item_type ) {
			// associated object is missing or not imported yet, we'll retry later
			// $missing_menu_items[] = $item;
			return;
		}
	}

	$post_parent = ( $post['post_type'] == 'nav_menu_item' ) ? $post['meta_input']['_menu_item_menu_item_parent'] : (int) $post['post_parent'];
	$post['post_parent'] = 0;
	if ( $post_parent ) {
		// if we already know the parent, map it to the new local ID
		if ( isset( $processed_posts[ $post_parent ] ) ) {
			if( $post['post_type'] == 'nav_menu_item' ) {
				$post['meta_input']['_menu_item_menu_item_parent'] = $processed_posts[ $post_parent ];
			} else {
				$post['post_parent'] = $processed_posts[ $post_parent ];
			}
		}
	}

	/**
	 * for hierarchical taxonomies, IDs must be used so wp_set_post_terms can function properly
	 * convert term slugs to IDs for hierarchical taxonomies
	 */
	if( ! empty( $post['tax_input'] ) ) {
		foreach( $post['tax_input'] as $tax => $terms ) {
			if( is_taxonomy_hierarchical( $tax ) ) {
				$terms = explode( ', ', $terms );
				$post['tax_input'][ $tax ] = array_map( 'themify_get_term_id_by_slug', $terms, array_fill( 0, count( $terms ), $tax ) );
			}
		}
	}

	$post['post_author'] = (int) get_current_user_id();
	$post['post_status'] = 'publish';

	$old_id = $post['ID'];

	unset( $post['ID'] );
	$post_id = wp_insert_post( $post, true );
	if( is_wp_error( $post_id ) ) {
		return false;
	} else {
		$processed_posts[ $old_id ] = $post_id;

		return $post_id;
	}
}

function themify_get_placeholder_image() {
	static $placeholder_image = null;

	if( $placeholder_image == null ) {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}
		WP_Filesystem();
		global $wp_filesystem;
		$upload = wp_upload_bits( $post['post_name'] . '.jpg', null, $wp_filesystem->get_contents( THEMIFY_DIR . '/img/image-placeholder.jpg' ) );

		if ( $info = wp_check_filetype( $upload['file'] ) )
			$post['post_mime_type'] = $info['type'];
		else
			return new WP_Error( 'attachment_processing_error', __( 'Invalid file type', 'themify' ) );

		$post['guid'] = $upload['url'];
		$post_id = wp_insert_attachment( $post, $upload['file'] );
		wp_update_attachment_metadata( $post_id, wp_generate_attachment_metadata( $post_id, $upload['file'] ) );

		$placeholder_image = $post_id;
	}

	return $placeholder_image;
}

function themify_import_term( $term ) {
	global $processed_terms;

	if( $term_id = term_exists( $term['slug'], $term['taxonomy'] ) ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term['term_id'] ) )
			$processed_terms[ intval( $term['term_id'] ) ] = (int) $term_id;
		return (int) $term_id;
	}

	if ( empty( $term['parent'] ) ) {
		$parent = 0;
	} else {
		$parent = term_exists( $processed_terms[ intval( $term['parent'] ) ], $term['taxonomy'] );
		if ( is_array( $parent ) ) $parent = $parent['term_id'];
	}

	$id = wp_insert_term( $term['name'], $term['taxonomy'], array(
		'parent' => $parent,
		'slug' => $term['slug'],
		'description' => $term['description'],
	) );
	if ( ! is_wp_error( $id ) ) {
		if ( isset( $term['term_id'] ) ) {
			// success!
			$processed_terms[ intval($term['term_id']) ] = $id['term_id'];
			if ( isset( $term['thumbnail'] ) ) {
				themify_add_import_action( 'term_thumb', array(
					'id' => $id['term_id'],
					'thumb' => $term['thumbnail'],
				) );
			}
			return $term['term_id'];
		}
	}

	return false;
}

function themify_get_term_id_by_slug( $slug, $tax ) {
	$term = get_term_by( 'slug', $slug, $tax );
	if( $term ) {
		return $term->term_id;
	}

	return false;
}

function themify_undo_import_term( $term ) {
	$term_id = term_exists( $term['slug'], $term['taxonomy'] );
	if ( $term_id ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];

		if ( $term_thumbnail = get_term_meta( $term['term_id'], 'thumbnail_id', true ) ) {
			wp_delete_attachment( $term_thumbnail, true );
		}

		if ( isset( $term_id ) ) {
			wp_delete_term( $term_id, $term['taxonomy'] );
		}
	}
}

/**
 * Determine if a post exists based on title, content, and date
 *
 * @global wpdb $wpdb WordPress database abstraction object.
 *
 * @param array $args array of database parameters to check
 * @return int Post ID if post exists, 0 otherwise.
 */
function themify_post_exists( $args = array() ) {
	global $wpdb;

	$query = "SELECT ID FROM $wpdb->posts WHERE 1=1";
	$db_args = array();

	foreach ( $args as $key => $value ) {
		$value = wp_unslash( sanitize_post_field( $key, $value, 0, 'db' ) );
		if( ! empty( $value ) ) {
			$query .= ' AND ' . $key . ' = %s';
			$db_args[] = $value;
		}
	}

	if ( !empty ( $args ) )
		return (int) $wpdb->get_var( $wpdb->prepare($query, $args) );

	return 0;
}

function themify_undo_import_post( $post ) {
	if( $post['post_type'] == 'nav_menu_item' ) {
		$post_exists = themify_post_exists( array(
			'post_name' => $post['post_name'],
			'post_modified' => $post['post_date'],
			'post_type' => 'nav_menu_item',
		) );
	} else {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
	}
	if( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
		/**
		 * check if the post has been modified, if so leave it be
		 *
		 * NOTE: posts are imported using wp_insert_post() which modifies post_modified field
		 * to be the same as post_date, hence to check if the post has been modified,
		 * the post_modified field is compared against post_date in the original post.
		 */
		if( $post['post_date'] == get_post_field( 'post_modified', $post_exists ) ) {
			// find and remove all post attachments
			$attachments = get_posts( array(
				'post_type' => 'attachment',
				'posts_per_page' => -1,
				'post_parent' => $post_exists,
			) );
			if ( $attachments ) {
				foreach ( $attachments as $attachment ) {
					wp_delete_attachment( $attachment->ID, true );
				}
			}
			wp_delete_post( $post_exists, true ); // true: bypass trash
		}
	}
}

function themify_process_post_import( $post ) {
	if( ERASEDEMO ) {
		themify_undo_import_post( $post );
	} else {
		if ( $id = themify_import_post( $post ) ) {
			if ( defined( 'IMPORT_IMAGES' ) && ! IMPORT_IMAGES ) {
				/* if importing images is disabled and post is supposed to have a thumbnail, create a placeholder image instead */
				if ( isset( $post['thumb'] ) ) { // the post is supposed to have featured image
					$placeholder = themify_get_placeholder_image();
					if( ! is_wp_error( $placeholder ) ) {
						set_post_thumbnail( $id, $placeholder );
					}
				}
			} else {
				if ( isset( $post["thumb"] ) ) {
					themify_add_import_action( 'post_thumb', array(
						'id' => $id,
						'thumb' => $post["thumb"],
					) );
				}
				if ( isset( $post["gallery_shortcode"] ) ) {
					themify_add_import_action( 'gallery_field', array(
						'id' => $id,
						'fields' => $post["gallery_shortcode"],
					) );
				}
			}
		}
	}
}
$thumbs = array();
function themify_do_demo_import() {
global $import_actions;

	if ( isset( $GLOBALS["ThemifyBuilder_Data_Manager"] ) ) {
		remove_action( "save_post", array( $GLOBALS["ThemifyBuilder_Data_Manager"], "save_builder_text_only"), 10, 3 );
	}
$term = array (
  'term_id' => 14,
  'name' => 'Blog',
  'slug' => 'blog',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 34,
  'name' => 'Images',
  'slug' => 'images',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 35,
  'name' => 'News',
  'slug' => 'news',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 36,
  'name' => 'Sports',
  'slug' => 'sports',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 35,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 37,
  'name' => 'Top Stories',
  'slug' => 'top-stories',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 35,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 42,
  'name' => 'Featured',
  'slug' => 'featured',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 35,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 44,
  'name' => 'gallery',
  'slug' => 'gallery-2',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 16,
  'name' => 'Games',
  'slug' => 'games',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 20,
  'name' => 'Hoodies',
  'slug' => 'hoodies',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 21,
  'name' => 'Jacket',
  'slug' => 'jacket',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 24,
  'name' => 'Shoes',
  'slug' => 'shoes',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 26,
  'name' => 'Tshirts',
  'slug' => 'tshirts',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 15,
  'name' => 'Blue',
  'slug' => 'blue',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 17,
  'name' => 'Gray',
  'slug' => 'gray',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 18,
  'name' => 'Green',
  'slug' => 'green',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 27,
  'name' => 'Yellow',
  'slug' => 'yellow',
  'term_group' => 0,
  'taxonomy' => 'pa_color',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 22,
  'name' => 'Large',
  'slug' => 'large',
  'term_group' => 0,
  'taxonomy' => 'pa_size',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 23,
  'name' => 'Medium',
  'slug' => 'medium',
  'term_group' => 0,
  'taxonomy' => 'pa_size',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 25,
  'name' => 'Small',
  'slug' => 'small',
  'term_group' => 0,
  'taxonomy' => 'pa_size',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 31,
  'name' => 'Main Nav',
  'slug' => 'main-nav',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 33,
  'name' => 'Footer Nav',
  'slug' => 'footer-nav',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$post = array (
  'ID' => 2080,
  'post_date' => '2008-06-11 20:22:47',
  'post_date_gmt' => '2008-06-11 20:22:47',
  'post_content' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi ac lobortis orci, a ornare dui. Phasellus consequat vulputate dignissim. Etiam condimentum aliquam augue, a ullamcorper erat facilisis et. Proin congue augue sit amet ligula dictum porta. Integer pharetra euismod velit ac laoreet. Ut dictum vitae ligula sed fermentum. Sed dapibus purus sit amet massa faucibus varius. Proin nec malesuada libero.',
  'post_title' => 'Butterfly Light',
  'post_excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Morbi ac lobortis orci...',
  'post_name' => 'butterfly-light',
  'post_modified' => '2017-08-24 05:21:51',
  'post_modified_gmt' => '2017-08-24 05:21:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=6',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/127880648.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2081,
  'post_date' => '2008-06-11 20:27:11',
  'post_date_gmt' => '2008-06-11 20:27:11',
  'post_content' => 'Integer ultrices turpis laoreet tellus venenatis, sed luctus libero gravida. Vestibulum eu hendrerit eros. Quisque eget luctus turpis, eget cursus velit. Nullam auctor ligula velit, fringilla molestie elit mattis et. Donec volutpat adipiscing urna, at egestas odio venenatis aliquet.',
  'post_title' => 'Sunset',
  'post_excerpt' => 'Integer ultrices turpis laoreet tellus venenatis, sed luctus libero gravida.',
  'post_name' => 'sunset',
  'post_modified' => '2017-08-24 05:21:50',
  'post_modified_gmt' => '2017-08-24 05:21:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=8',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/60795601.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2082,
  'post_date' => '2008-06-11 20:38:30',
  'post_date_gmt' => '2008-06-11 20:38:30',
  'post_content' => 'Vestibulum a quam nisl. Nam sagittis neque erat, sed egestas urna facilisis et. Cras interdum imperdiet est, ac porttitor sapien porttitor id. Aenean semper congue dolor, non malesuada sapien. Sed neque diam, cursus eget eros at, pretium sagittis ligula. Sed pretium urna vitae velit pharetra',
  'post_title' => 'Late Stroll',
  'post_excerpt' => 'Vestibulum a quam nisl. Nam sagittis neque erat, sed egestas urna facilisis et.',
  'post_name' => 'late-stroll',
  'post_modified' => '2017-08-24 05:21:48',
  'post_modified_gmt' => '2017-08-24 05:21:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=22',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/134602640.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 25,
  'post_date' => '2008-06-11 20:41:16',
  'post_date_gmt' => '2008-06-11 20:41:16',
  'post_content' => 'Etiam ipsum ligula, mollis eu vestibulum id, ornare vel nibh. Sed sollicitudin, arcu non auctor pulvinar, velit eros viverra sapien, a mattis sem tortor sed arcu. Aenean gravida tincidunt commodo. In felis nunc, ultricies vel congue nec, congue vitae lacus.',
  'post_title' => 'Empty House',
  'post_excerpt' => 'Etiam ipsum ligula, mollis eu vestibulum id, ornare vel nibh. Sed sollicitudin, arcu non...',
  'post_name' => 'empty-house',
  'post_modified' => '2017-08-24 05:21:46',
  'post_modified_gmt' => '2017-08-24 05:21:46',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=25',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/92168305.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 28,
  'post_date' => '2008-06-11 20:42:29',
  'post_date_gmt' => '2008-06-11 20:42:29',
  'post_content' => 'Vestibulum malesuada neque nec hendrerit lobortis. Maecenas erat diam, fringilla et hendrerit eu, laoreet vel quam. Integer sollicitudin nec eros a fringilla. Mauris sed velit sapien. Pellentesque habitant morbi tristique senectus et netus et malesuada.',
  'post_title' => 'Sweet Tooth',
  'post_excerpt' => 'Vestibulum malesuada neque nec hendrerit lobortis. Maecenas erat diam, fringilla...',
  'post_name' => 'sweet-tooth',
  'post_modified' => '2017-08-24 05:21:44',
  'post_modified_gmt' => '2017-08-24 05:21:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=28',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/99449315.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 31,
  'post_date' => '2008-06-11 20:45:36',
  'post_date_gmt' => '2008-06-11 20:45:36',
  'post_content' => 'Sed pharetra fringilla venenatis. Quisque quis lobortis nibh, nec egestas leo. Cras id augue id nulla interdum feugiat. Cras quam lacus, congue at consequat sit amet, consectetur id enim. Sed id lorem id turpis ultrices mattis at a odio.',
  'post_title' => 'Lightbox Link',
  'post_excerpt' => 'Sed pharetra fringilla venenatis. Quisque quis lobortis nibh, nec egestas leo.',
  'post_name' => 'lightbox-link',
  'post_modified' => '2017-08-24 05:21:42',
  'post_modified_gmt' => '2017-08-24 05:21:42',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=31',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'lightbox_link' => 'https://themify.me/demo/themes/builder/files/2013/06/129025022.jpg',
    'lightbox_icon' => 'on',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/129025022.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2088,
  'post_date' => '2008-06-11 20:58:56',
  'post_date_gmt' => '2008-06-11 20:58:56',
  'post_content' => 'Sed pharetra fringilla venenatis. Quisque quis lobortis nibh, nec egestas leo. Pellentesque ornare auctor velit eget rutrum. Vivamus enim quam, commodo auctor erat sed, sodales tristique erat.

[gallery link="file" columns="6" ids="36,37,38,39,40,41"]',
  'post_title' => 'Gallery Post',
  'post_excerpt' => 'Sed pharetra fringilla venenatis. Quisque quis lobortis nibh, nec egestas leo.',
  'post_name' => 'gallery-post',
  'post_modified' => '2017-08-24 05:21:41',
  'post_modified_gmt' => '2017-08-24 05:21:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=34',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
    'post_tag' => 'gallery-2',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/56310136.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 46,
  'post_date' => '2008-06-11 21:08:52',
  'post_date_gmt' => '2008-06-11 21:08:52',
  'post_content' => 'Proin ornare scelerisque tellus, at porttitor urna pharetra in. Quisque mattis nibh sed dui fermentum, at porttitor nunc egestas. Vestibulum arcu eros, ultricies et ultricies scelerisque, gravida a eros. Nam eget commodo purus, quis mattis dui. Nunc vulputate rutrum odio vitae euismod.',
  'post_title' => 'Lightbox Video',
  'post_excerpt' => 'Proin ornare scelerisque tellus, at porttitor urna pharetra in. Quisque mattis nibh sed dui...',
  'post_name' => 'lightbox-video',
  'post_modified' => '2017-08-24 05:21:39',
  'post_modified_gmt' => '2017-08-24 05:21:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=46',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'lightbox_link' => 'http://vimeo.com/60779545',
    'lightbox_icon' => 'on',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/26990563.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 2089,
  'post_date' => '2008-06-11 21:16:04',
  'post_date_gmt' => '2008-06-11 21:16:04',
  'post_content' => 'Ut tempus nibh elit, eu faucibus lorem fringilla sed. Phasellus lobortis urna eget eleifend aliquet. Cras id augue id nulla interdum feugiat. Cras quam lacus, congue at consequat sit amet, consectetur id enim. Sed id lorem id turpis ultrices mattis at a odio.',
  'post_title' => 'External Link',
  'post_excerpt' => 'Ut tempus nibh elit, eu faucibus lorem fringilla sed. Phasellus lobortis urna eget.',
  'post_name' => 'external-link',
  'post_modified' => '2017-08-24 05:21:37',
  'post_modified_gmt' => '2017-08-24 05:21:37',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=50',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
    'external_link' => 'https://themify.me/',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/59006500.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 53,
  'post_date' => '2008-06-11 21:19:37',
  'post_date_gmt' => '2008-06-11 21:19:37',
  'post_content' => 'Mauris faucibus, tellus sed commodo luctus, nibh libero tristique felis, a vulputate nibh tellus et purus. Donec dictum odio non magna accumsan pellentesque. Sed pharetra fringilla venenatis. Quisque quis lobortis nibh, nec egestas leo.',
  'post_title' => 'Landscape',
  'post_excerpt' => 'Mauris faucibus, tellus sed commodo luctus, nibh libero tristique felis, a vulputate nibh...',
  'post_name' => 'landscape',
  'post_modified' => '2017-08-24 05:21:36',
  'post_modified_gmt' => '2017-08-24 05:21:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=53',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog, images',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/65799673.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1762,
  'post_date' => '2008-06-25 02:01:43',
  'post_date_gmt' => '2008-06-25 02:01:43',
  'post_content' => 'Nam risus velit, rhoncus eget consectetur id, <a href="https://themify.me/">Themify.me</a>. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit.',
  'post_title' => 'Top 10 Office Entertainment Gadgets',
  'post_excerpt' => '',
  'post_name' => 'top-10-office-entertainment-gadgets',
  'post_modified' => '2017-08-24 05:21:22',
  'post_modified_gmt' => '2017-08-24 05:21:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1762',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'featured',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/sb10064068ac-001.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1766,
  'post_date' => '2008-06-25 02:02:31',
  'post_date_gmt' => '2008-06-25 02:02:31',
  'post_content' => 'Aliquam erat nulla, sodales at imperdiet vitae, convallis vel dui. Sed ultrices felis ut justo suscipit vestibulum. Pellentesque nisl nisi, vehicula vitae hendrerit vel, mattis eget mauris. Donec consequat eros eget lectus dictum sit amet ultrices neque sodales. Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla.',
  'post_title' => 'How to Stay Connected on the Go',
  'post_excerpt' => '',
  'post_name' => 'how-to-stay-connected-on-the-go',
  'post_modified' => '2017-08-24 05:21:20',
  'post_modified_gmt' => '2017-08-24 05:21:20',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1766',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'featured',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/75627871.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1769,
  'post_date' => '2008-06-25 02:03:33',
  'post_date_gmt' => '2008-06-25 02:03:33',
  'post_content' => 'Nunc et pharetra enim. Praesent pharetra, neque et luctus tempor, leo sapien faucibus leo, a dignissim turpis ipsum sed libero. Sed sed luctus purus. Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu.',
  'post_title' => 'Are Your Kids Under Stress?',
  'post_excerpt' => '',
  'post_name' => 'are-your-kids-under-stress',
  'post_modified' => '2017-08-24 05:21:18',
  'post_modified_gmt' => '2017-08-24 05:21:18',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1769',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'featured',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/83109689.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1772,
  'post_date' => '2008-06-25 02:04:04',
  'post_date_gmt' => '2008-06-25 02:04:04',
  'post_content' => 'Vivamus in risus non lacus vehicula vestibulum. In magna leo, malesuada eget pulvinar ut, pellentesque a arcu. Praesent rutrum feugiat nibh elementum posuere. Nulla volutpat porta enim vel consectetur.',
  'post_title' => '10 Travel Tips for Your Summer Vacation',
  'post_excerpt' => '',
  'post_name' => '10-travel-tips-for-your-summer-vacation',
  'post_modified' => '2017-08-24 05:21:16',
  'post_modified_gmt' => '2017-08-24 05:21:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1772',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'featured',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/106390351.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1775,
  'post_date' => '2008-06-25 02:04:40',
  'post_date_gmt' => '2008-06-25 02:04:40',
  'post_content' => 'Mauris varius fermentum velit sit amet varius. Aenean consectetur lacus tellus, sed vestibulum quam. Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purus, ac varius ante purus sed diam.',
  'post_title' => 'How to Shop for Healthy Fruits',
  'post_excerpt' => '',
  'post_name' => 'how-to-shop-for-healthy-fruits',
  'post_modified' => '2017-08-24 05:21:15',
  'post_modified_gmt' => '2017-08-24 05:21:15',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1775',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'featured',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/86527435.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1802,
  'post_date' => '2008-06-26 00:43:06',
  'post_date_gmt' => '2008-06-26 00:43:06',
  'post_content' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam lobortis ac tellus id tempor. Aliquam pellentesque nibh quis justo commodo tristique. Aliquam erat volutpat. Etiam ut justo aliquam, euismod dolor eget, ullamcorper tortor. Aliquam eu ipsum a urna lacinia aliquam id non dui.',
  'post_title' => 'Travel the world',
  'post_excerpt' => '',
  'post_name' => 'travel-the-world',
  'post_modified' => '2017-08-24 05:21:14',
  'post_modified_gmt' => '2017-08-24 05:21:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1802',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'top-stories',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/83719858.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1805,
  'post_date' => '2008-06-26 00:44:06',
  'post_date_gmt' => '2008-06-26 00:44:06',
  'post_content' => 'Fusce hendrerit adipiscing diam vitae sodales. Sed faucibus venenatis lectus sed laoreet. Sed in libero ac nisi placerat dictum. Donec dui neque, aliquam non nunc nec, porttitor tempor leo. Maecenas non sagittis neque.',
  'post_title' => 'Morning News',
  'post_excerpt' => '',
  'post_name' => 'morning-news',
  'post_modified' => '2017-08-24 05:21:11',
  'post_modified_gmt' => '2017-08-24 05:21:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1805',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'top-stories',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/74878789.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1808,
  'post_date' => '2008-06-26 00:45:33',
  'post_date_gmt' => '2008-06-26 00:45:33',
  'post_content' => 'Duis laoreet tortor magna, sit amet viverra elit dignissim sit amet. Aenean tempor et tortor eget blandit. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Sed aliquam, sapien et tincidunt sodales, risus lectus rutrum turpis.',
  'post_title' => 'Greenhouse Plants',
  'post_excerpt' => '',
  'post_name' => 'greenhouse-plants',
  'post_modified' => '2017-08-24 05:21:10',
  'post_modified_gmt' => '2017-08-24 05:21:10',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1808',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'top-stories',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/86807268.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1811,
  'post_date' => '2008-06-26 00:46:53',
  'post_date_gmt' => '2008-06-26 00:46:53',
  'post_content' => 'Duis diam urna, aliquam id mauris nec, tristique ultrices turpis. Nam non ante in nunc euismod rutrum. Cras tristique feugiat neque sed vestibulum.',
  'post_title' => 'Shop on the Run',
  'post_excerpt' => '',
  'post_name' => 'shop-on-the-run',
  'post_modified' => '2017-08-24 05:21:09',
  'post_modified_gmt' => '2017-08-24 05:21:09',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1811',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'top-stories',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/106564386.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 1815,
  'post_date' => '2008-06-26 00:51:24',
  'post_date_gmt' => '2008-06-26 00:51:24',
  'post_content' => 'Sed eu urna quis lacus aliquet fermentum vel sed risus. Integer laoreet pretium interdum. Proin consequat consequat feugiat. Integer pellentesque faucibus aliquet.',
  'post_title' => 'The Desert Run',
  'post_excerpt' => '',
  'post_name' => 'the-desert-run',
  'post_modified' => '2017-08-24 05:21:04',
  'post_modified_gmt' => '2017-08-24 05:21:04',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/builder/?p=1815',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'content_width' => 'default_width',
    'layout' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'unlink_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'sports',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2013/06/86536315.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 6,
  'post_date' => '2012-02-17 16:21:42',
  'post_date_gmt' => '2012-02-17 16:21:42',
  'post_content' => '<!--themify_builder_static--><p>Box content</p><!--/themify_builder_static-->',
  'post_title' => 'Shop',
  'post_excerpt' => '',
  'post_name' => 'shop',
  'post_modified' => '2017-10-28 01:09:56',
  'post_modified_gmt' => '2017-10-28 01:09:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/shop/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 7,
  'post_date' => '2012-02-17 16:21:42',
  'post_date_gmt' => '2012-02-17 16:21:42',
  'post_content' => '[woocommerce_cart]',
  'post_title' => 'Cart',
  'post_excerpt' => '',
  'post_name' => 'cart',
  'post_modified' => '2017-08-24 05:23:12',
  'post_modified_gmt' => '2017-08-24 05:23:12',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/cart/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 8,
  'post_date' => '2012-02-17 16:21:42',
  'post_date_gmt' => '2012-02-17 16:21:42',
  'post_content' => '[woocommerce_checkout]',
  'post_title' => 'Checkout',
  'post_excerpt' => '',
  'post_name' => 'checkout',
  'post_modified' => '2017-08-24 05:23:14',
  'post_modified_gmt' => '2017-08-24 05:23:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/checkout/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 10,
  'post_date' => '2012-02-17 16:21:42',
  'post_date_gmt' => '2012-02-17 16:21:42',
  'post_content' => '[woocommerce_my_account]',
  'post_title' => 'My Account',
  'post_excerpt' => '',
  'post_name' => 'my-account',
  'post_modified' => '2017-08-24 05:23:30',
  'post_modified_gmt' => '2017-08-24 05:23:30',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/my-account/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 12,
  'post_date' => '2012-02-17 16:21:42',
  'post_date_gmt' => '2012-02-17 16:21:42',
  'post_content' => '[woocommerce_view_order]',
  'post_title' => 'View Order',
  'post_excerpt' => '',
  'post_name' => 'view-order',
  'post_modified' => '2017-08-24 05:23:31',
  'post_modified_gmt' => '2017-08-24 05:23:31',
  'post_content_filtered' => '',
  'post_parent' => 10,
  'guid' => 'https://themify.me/demo/themes/shopdock/my-account/view-order/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 121,
  'post_date' => '2012-02-27 06:43:35',
  'post_date_gmt' => '2012-02-27 06:43:35',
  'post_content' => '',
  'post_title' => 'Blog',
  'post_excerpt' => '',
  'post_name' => 'blog',
  'post_modified' => '2017-08-24 05:23:06',
  'post_modified_gmt' => '2017-08-24 05:23:06',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=121',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-thumb-image',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 123,
  'post_date' => '2012-02-27 06:44:14',
  'post_date_gmt' => '2012-02-27 06:44:14',
  'post_content' => '',
  'post_title' => 'Blog - 4 Columns',
  'post_excerpt' => '',
  'post_name' => 'blog-4-columns',
  'post_modified' => '2017-08-24 05:23:10',
  'post_modified_gmt' => '2017-08-24 05:23:10',
  'post_content_filtered' => '',
  'post_parent' => 121,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=123',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'grid4',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 126,
  'post_date' => '2012-02-27 06:44:43',
  'post_date_gmt' => '2012-02-27 06:44:43',
  'post_content' => '',
  'post_title' => 'Blog - 3 Columns',
  'post_excerpt' => '',
  'post_name' => 'blog-3-columns',
  'post_modified' => '2017-08-24 05:23:08',
  'post_modified_gmt' => '2017-08-24 05:23:08',
  'post_content_filtered' => '',
  'post_parent' => 121,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=126',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'grid3',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 128,
  'post_date' => '2012-02-27 06:45:03',
  'post_date_gmt' => '2012-02-27 06:45:03',
  'post_content' => '',
  'post_title' => 'Blog - 2 Columns',
  'post_excerpt' => '',
  'post_name' => 'blog-2-columns',
  'post_modified' => '2017-08-24 05:23:07',
  'post_modified_gmt' => '2017-08-24 05:23:07',
  'post_content_filtered' => '',
  'post_parent' => 121,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=128',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'grid2',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 139,
  'post_date' => '2012-02-27 06:50:25',
  'post_date_gmt' => '2012-02-27 06:50:25',
  'post_content' => 'Download this contact plugin: <a href="http://wordpress.org/extend/plugins/contact-form-7">Contact Form 7</a>.

[contact-form-7 id="141" title="Untitled"]',
  'post_title' => 'Contact',
  'post_excerpt' => '',
  'post_name' => 'contact',
  'post_modified' => '2017-08-24 05:23:16',
  'post_modified_gmt' => '2017-08-24 05:23:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=139',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 146,
  'post_date' => '2012-02-27 06:52:29',
  'post_date_gmt' => '2012-02-27 06:52:29',
  'post_content' => '',
  'post_title' => 'Map',
  'post_excerpt' => '',
  'post_name' => 'map',
  'post_modified' => '2017-08-25 02:50:39',
  'post_modified_gmt' => '2017-08-25 02:50:39',
  'post_content_filtered' => '',
  'post_parent' => 139,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=146',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"mod_settings\\":{\\"map_display_type\\":\\"dynamic\\",\\"address_map\\":\\"Yonge St. and Eglinton Ave, Toronto, Ontario, Canada\\",\\"zoom_map\\":\\"15\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"h_map\\":\\"600\\",\\"unit_h\\":\\"px\\",\\"b_style_map\\":\\"solid\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"solid\\",\\"border_right_style\\":\\"solid\\",\\"border_bottom_style\\":\\"solid\\",\\"border_left_style\\":\\"solid\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Direction</h3><p>We are located at Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu.</p><h3>Address</h3><p>123 Street Name,<br /> City, Province<br /> 23446</p><h3>Phone</h3><p>236-298-2828</p><h3>Hours</h3><p>Mon - Fri : 11:00am - 10:00pm<br /> Sat : 11:00am - 2:00pm<br /> Sun : 12:00am - 11:00pm</p>\\",\\"column_divider_style\\":\\"solid\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"solid\\",\\"border_right_style\\":\\"solid\\",\\"border_bottom_style\\":\\"solid\\",\\"border_left_style\\":\\"solid\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 152,
  'post_date' => '2012-02-27 06:53:58',
  'post_date_gmt' => '2012-02-27 06:53:58',
  'post_content' => '<h3>Buttons</h3>
[button style="orange" link="https://themify.me"]Orange[/button] [button style="blue"]Blue[/button] [button style="pink"]Pink[/button] [button style="green"]Green[/button] [button style="red"]Red[/button] [button style="black"]Black[/button]

[hr]

[button style="small"]Small[/button]

[button]Default[/button]

[button style="large"]Large[/button] [button style="xlarge"]Xlarge[/button]

[hr]

[button style="orange small"]Orange Small[/button] [button style="blue"]Blue[/button] [button style="green large"]Green Large[/button] [button style="red xlarge"]Red Xlarge[/button]

[hr]
<h3>Columns</h3>
[col grid="2-1 first"]
<h4>col 2-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg.

[/col]

[col grid="2-1"]
<h4>col 2-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa.

[/col]

[hr]

[col grid="3-1 first"]
<h4>col 3-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg.

[/col]

[col grid="3-1"]
<h4>col 3-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa.

[/col]

[col grid="3-1"]
<h4>col 3-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit.

[/col]

[hr]

[col grid="4-1 first"]
<h4>col 4-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget co.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit diam.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Donec porttitor hendrerit diam et blandit. Curabitur vel risus eros, sed eleifend arcu. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[hr]

[col grid="4-2 first"]
<h4>col 4-2</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget cout rhoncus turpis augue vitae libero.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit diam.

[/col]
<h3>Horizontal Rules</h3>
[hr]

[hr color="pink"]

[hr color="red"]

[hr color="light-gray"]

[hr color="dark-gray"]

[hr color="black"]

[hr color="orange"]

[hr color="yellow"]

[hr color="white"]
<h3>Quote</h3>
[quote]Vivamus in risus non lacus vehicula vestibulum. In magna leo, malesuada eget pulvinar ut, pellentesque a arcu. Praesent rutrum feugiat nibh elementum posuere. Nulla volutpat porta enim vel consectetur. Etiam orci eros, blandit nec egestas eget, pharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae. Cras laoreet hendrerit erat, id porttitor nunc blandit adipiscing. [/quote]
<h3>Map</h3>
[map address="Yonge St. and Eglinton Ave, Toronto, Ontario, Canada" width=100% height=400px]',
  'post_title' => 'Shortcodes',
  'post_excerpt' => '',
  'post_name' => 'shortcodes',
  'post_modified' => '2017-08-24 05:23:34',
  'post_modified_gmt' => '2017-08-24 05:23:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?page_id=152',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'section_categories' => 'default',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 161,
  'post_date' => '2012-04-13 00:20:52',
  'post_date_gmt' => '2012-04-13 00:20:52',
  'post_content' => '',
  'post_title' => 'Slide3',
  'post_excerpt' => '',
  'post_name' => 'slide3',
  'post_modified' => '2017-08-24 05:22:28',
  'post_modified_gmt' => '2017-08-24 05:22:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?post_type=slider&#038;p=161',
  'menu_order' => 0,
  'post_type' => 'slider',
  'meta_input' => 
  array (
    'layout' => 'slider-image-only',
    'feature_image' => 'https://themify.me/demo/themes/minshop/files/2012/04/slide3.jpg',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 162,
  'post_date' => '2012-04-13 00:21:09',
  'post_date_gmt' => '2012-04-13 00:21:09',
  'post_content' => '',
  'post_title' => 'Slide2',
  'post_excerpt' => '',
  'post_name' => 'slide2',
  'post_modified' => '2017-08-24 05:22:28',
  'post_modified_gmt' => '2017-08-24 05:22:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?post_type=slider&#038;p=162',
  'menu_order' => 0,
  'post_type' => 'slider',
  'meta_input' => 
  array (
    'layout' => 'slider-image-only',
    'feature_image' => 'https://themify.me/demo/themes/minshop/files/2012/04/slide2.jpg',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 163,
  'post_date' => '2012-04-13 00:21:28',
  'post_date_gmt' => '2012-04-13 00:21:28',
  'post_content' => '',
  'post_title' => 'Slide1',
  'post_excerpt' => '',
  'post_name' => 'slide1',
  'post_modified' => '2017-08-24 05:22:17',
  'post_modified_gmt' => '2017-08-24 05:22:17',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?post_type=slider&#038;p=163',
  'menu_order' => 0,
  'post_type' => 'slider',
  'meta_input' => 
  array (
    'layout' => 'slider-image-only',
    'feature_image' => 'https://themify.me/demo/themes/minshop/files/2012/04/slide1.jpg',
  ),
  'tax_input' => 
  array (
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 22,
  'post_date' => '2012-02-23 19:22:45',
  'post_date_gmt' => '2012-02-23 19:22:45',
  'post_content' => 'Duis id tincidunt tortor. Curabitur placerat luctus lacinia. In hac habitasse platea dictumst. Suspendisse potenti. Nunc vestibulum, erat et pharetra aliquet, mi nunc iaculis erat, in pharetra libero felis sit amet ipsum.',
  'post_title' => 'Super Monkey Ball',
  'post_excerpt' => '',
  'post_name' => 'super-monkey-ball',
  'post_modified' => '2017-08-24 05:24:48',
  'post_modified_gmt' => '2017-08-24 05:24:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=22',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '20',
    '_sale_price' => '18',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '18',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_thumbnail_id' => '57',
    'total_sales' => '3',
    '_wc_rating_count' => 
    array (
      4 => '1',
    ),
    '_wc_average_rating' => '4.00',
    '_wc_review_count' => '1',
    '_edit_lock' => '1503552155:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_product_image_gallery' => '23',
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/monkey-ball.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/monkey-ball.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 26,
  'post_date' => '2012-02-23 21:32:23',
  'post_date_gmt' => '2012-02-23 21:32:23',
  'post_content' => 'Ut eleifend rhoncus augue sit amet dignissim. In mattis lobortis imperdiet. Aliquam molestie nisi et purus mattis volutpat. Cras dignissim, arcu vel pretium interdum, turpis sapien rutrum felis, non condimentum nulla orci ornare tellus.',
  'post_title' => 'Black Hood',
  'post_excerpt' => '',
  'post_name' => 'black-hood',
  'post_modified' => '2017-10-28 00:16:14',
  'post_modified_gmt' => '2017-10-28 00:16:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=26',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
      'pa_size' => 
      array (
        'name' => 'pa_size',
        'value' => '',
        'position' => 1,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 1,
      ),
      'pa_color' => 
      array (
        'name' => 'pa_color',
        'value' => '',
        'position' => 2,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 1,
      ),
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '9',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_min_variation_price' => '9',
    '_max_variation_price' => '11',
    '_default_attributes' => 
    array (
    ),
    '_wp_old_slug' => 'hoodie',
    '_min_variation_regular_price' => '9',
    '_max_variation_regular_price' => '11',
    'total_sales' => '6',
    '_min_price_variation_id' => '48',
    '_max_price_variation_id' => '50',
    '_min_regular_price_variation_id' => '48',
    '_max_regular_price_variation_id' => '50',
    '_edit_lock' => '1503552154:172',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_content_score' => '30',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
    'product_type' => 'variable',
    'product_cat' => 'hoodies',
    'pa_color' => 'blue, gray, green, yellow',
    'pa_size' => 'large, medium, small',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 52,
  'post_date' => '2012-02-24 21:48:04',
  'post_date_gmt' => '2012-02-24 21:48:04',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Praesent venenatis purus convallis ipsum porttitor convallis consectetur orci condimentum. Curabitur ornare interdum pellentesque.',
  'post_title' => 'Bloody Mary',
  'post_excerpt' => '',
  'post_name' => 'bloody-mary',
  'post_modified' => '2017-08-24 05:24:41',
  'post_modified_gmt' => '2017-08-24 05:24:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=52',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_stock_status' => 'instock',
    '_edit_last' => '172',
    '_regular_price' => '18',
    '_tax_status' => 'taxable',
    '_thumbnail_id' => '61',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '18',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '4',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552152:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/bloody-mary.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/bloody-mary.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 54,
  'post_date' => '2012-02-24 21:50:23',
  'post_date_gmt' => '2012-02-24 21:50:23',
  'post_content' => 'Praesent eu ligula ut ligula tempus porttitor. In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra.',
  'post_title' => 'Donkey Kong',
  'post_excerpt' => '',
  'post_name' => 'donkey-kong',
  'post_modified' => '2017-08-24 05:24:39',
  'post_modified_gmt' => '2017-08-24 05:24:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=54',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '18',
    '_sale_price' => '15',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '15',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_thumbnail_id' => '59',
    'total_sales' => '2',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552152:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_product_image_gallery' => '55',
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/dk1.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/dk1.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 62,
  'post_date' => '2012-02-24 22:06:11',
  'post_date_gmt' => '2012-02-24 22:06:11',
  'post_content' => 'Vivamus in dolor eu lacus luctus auctor non ac turpis. Proin et rutrum dolor. Praesent venenatis purus convallis ipsum porttitor convallis consectetur orci condimentum. Curabitur ornare interdum pellentesque.',
  'post_title' => 'Puzzle Bobble',
  'post_excerpt' => '',
  'post_name' => 'puzzle-bobble',
  'post_modified' => '2017-08-24 05:24:38',
  'post_modified_gmt' => '2017-08-24 05:24:38',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=62',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '29',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '29',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_edit_lock' => '1503552151:172',
    'total_sales' => '2',
    '_thumbnail_id' => '166',
    '_wp_old_slug' => 'barbie',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_product_image_gallery' => '63,164',
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/puzzle-bobble.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/puzzle-bobble.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 65,
  'post_date' => '2012-02-24 22:08:10',
  'post_date_gmt' => '2012-02-24 22:08:10',
  'post_content' => 'Maecenas rhoncus malesuada aliquet. Morbi vulputate vulputate mauris quis condimentum. Ut ut ligula et mauris accumsan tristique ut nec lacus. Cras tempus pretium sagittis. Praesent porta libero nec magna vulputate porta.',
  'post_title' => 'PKM',
  'post_excerpt' => '',
  'post_name' => 'pkm',
  'post_modified' => '2017-08-24 05:24:36',
  'post_modified_gmt' => '2017-08-24 05:24:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=65',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '26',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '26',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_edit_lock' => '1503552150:172',
    '_wp_old_slug' => 'peppa-pig',
    'total_sales' => '4',
    '_thumbnail_id' => '168',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_product_image_gallery' => '66',
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/pkmnb-550x506.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/pkmnb-550x506.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 67,
  'post_date' => '2012-02-24 22:10:07',
  'post_date_gmt' => '2012-02-24 22:10:07',
  'post_content' => 'Ut ut ligula et mauris accumsan tristique ut nec lacus. Cras tempus pretium sagittis. Praesent porta libero nec magna vulputate porta. Maecenas rhoncus malesuada aliquet. Morbi vulputate vulputate mauris quis condimentum.',
  'post_title' => 'Ridge Racers 3D',
  'post_excerpt' => '',
  'post_name' => 'ridge-racers-3d',
  'post_modified' => '2017-08-24 05:24:34',
  'post_modified_gmt' => '2017-08-24 05:24:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=67',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '68',
    '_edit_last' => '172',
    '_regular_price' => '29',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '29',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552150:172',
    'total_sales' => '0',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/ridge-racers.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/ridge-racers.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 70,
  'post_date' => '2012-02-24 22:11:52',
  'post_date_gmt' => '2012-02-24 22:11:52',
  'post_content' => '',
  'post_title' => 'Pilotwings Resort',
  'post_excerpt' => '',
  'post_name' => 'pilotwings-resort',
  'post_modified' => '2017-08-24 05:24:32',
  'post_modified_gmt' => '2017-08-24 05:24:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=70',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '71',
    '_edit_last' => '172',
    '_regular_price' => '23',
    '_sale_price' => '15',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '15',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552148:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/pilotwinds-resort.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'games',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/pilotwinds-resort.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 72,
  'post_date' => '2012-02-24 22:12:51',
  'post_date_gmt' => '2012-02-24 22:12:51',
  'post_content' => 'Maecenas rhoncus malesuada aliquet. Morbi vulputate vulputate mauris quis condimentum. Ut ut ligula et mauris accumsan tristique ut nec lacus. Cras tempus pretium sagittis. Praesent porta libero nec magna vulputate porta.',
  'post_title' => 'Australia',
  'post_excerpt' => '',
  'post_name' => 'australia',
  'post_modified' => '2017-08-24 05:24:31',
  'post_modified_gmt' => '2017-08-24 05:24:31',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=72',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '169',
    '_edit_last' => '172',
    '_regular_price' => '28',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '28',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_edit_lock' => '1503552148:172',
    'total_sales' => '17',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_product_image_gallery' => '73',
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/grateful-dead.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/grateful-dead.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 74,
  'post_date' => '2012-02-24 22:13:48',
  'post_date_gmt' => '2012-02-24 22:13:48',
  'post_content' => 'In at sem ipsum, sed commodo felis. Nullam nec elit sapien. Donec at congue sapien. Mauris a diam nec felis auctor ultrices. Sed tempus mollis orci in viverra. Vivamus libero eros, dictum id aliquam in, tristique id sapien.',
  'post_title' => 'Elephant',
  'post_excerpt' => '',
  'post_name' => 'elephant',
  'post_modified' => '2017-08-24 05:24:29',
  'post_modified_gmt' => '2017-08-24 05:24:29',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=74',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '75',
    '_edit_last' => '172',
    '_regular_price' => '25',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '25',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '2',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552292:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/elephant.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'tshirts',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/elephant.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 77,
  'post_date' => '2012-02-24 22:15:42',
  'post_date_gmt' => '2012-02-24 22:15:42',
  'post_content' => 'Donec quis augue nibh, eu facilisis metus. Donec cursus condimentum erat quis sollicitudin. Mauris enim tortor, hendrerit ut pharetra non, eleifend non elit. Ut dapibus eleifend ipsum a rhoncus. Aenean eu ante felis, nec vulputate enim.',
  'post_title' => 'Bardenas',
  'post_excerpt' => '',
  'post_name' => 'bardenas',
  'post_modified' => '2017-08-24 05:24:27',
  'post_modified_gmt' => '2017-08-24 05:24:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=77',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_last' => '172',
    '_regular_price' => '69',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '69',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_thumbnail_id' => '78',
    'total_sales' => '13',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552147:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/Chukka-bardenas-720x720.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/Chukka-bardenas-720x720.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 80,
  'post_date' => '2012-02-24 22:18:10',
  'post_date_gmt' => '2012-02-24 22:18:10',
  'post_content' => 'Nullam dapibus semper risus eu accumsan. Nulla facilisis eros ac ligula sodales suscipit. Fusce pellentesque iaculis dignissim. Phasellus tristique neque vitae justo laoreet tempus.',
  'post_title' => 'Vansera',
  'post_excerpt' => '',
  'post_name' => 'vansera',
  'post_modified' => '2017-08-24 05:24:25',
  'post_modified_gmt' => '2017-08-24 05:24:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=80',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '81',
    '_edit_last' => '172',
    '_regular_price' => '79',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '79',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '18',
    '_wc_rating_count' => 
    array (
      5 => '1',
    ),
    '_wc_average_rating' => '5.00',
    '_wc_review_count' => '1',
    '_edit_lock' => '1503552146:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/vansera1-720x720.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/vansera1-720x720.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 83,
  'post_date' => '2012-02-24 22:32:25',
  'post_date_gmt' => '2012-02-24 22:32:25',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Era',
  'post_excerpt' => '',
  'post_name' => 'era',
  'post_modified' => '2017-08-24 05:24:23',
  'post_modified_gmt' => '2017-08-24 05:24:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=83',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '84',
    '_edit_last' => '172',
    '_regular_price' => '69',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '69',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '14',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552146:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/eraLX.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/eraLX.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 85,
  'post_date' => '2012-02-24 22:34:11',
  'post_date_gmt' => '2012-02-24 22:34:11',
  'post_content' => 'Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed. Proin non velit arcu, sit amet laoreet massa.',
  'post_title' => 'SK8',
  'post_excerpt' => '',
  'post_name' => 'sk8',
  'post_modified' => '2017-08-24 05:24:22',
  'post_modified_gmt' => '2017-08-24 05:24:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=85',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '86',
    '_edit_last' => '172',
    '_regular_price' => '79',
    '_sale_price' => '49',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'yes',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '49',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '22',
    '_wc_rating_count' => 
    array (
      5 => 1,
    ),
    '_wc_average_rating' => '5.00',
    '_wc_review_count' => '1',
    '_edit_lock' => '1503552145:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/Sk8-HI-720x720.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/Sk8-HI-720x720.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 87,
  'post_date' => '2012-02-23 22:35:36',
  'post_date_gmt' => '2012-02-23 22:35:36',
  'post_content' => 'Proin non velit arcu, sit amet laoreet massa. Aliquam gravida eros sit amet leo scelerisque molestie. Morbi et cursus felis. Pellentesque at dui nunc. Integer euismod tincidunt nisl, in iaculis tellus feugiat sed.',
  'post_title' => 'Black Jacket',
  'post_excerpt' => '',
  'post_name' => 'black-jacket',
  'post_modified' => '2017-08-24 05:24:45',
  'post_modified_gmt' => '2017-08-24 05:24:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=87',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '88',
    '_edit_last' => '172',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
      'size' => 
      array (
        'name' => 'Size',
        'value' => 'Large | Xlarge',
        'position' => 2,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
      'color' => 
      array (
        'name' => 'Color',
        'value' => 'Black | Gray | Green',
        'position' => 3,
        'is_visible' => 1,
        'is_variation' => 1,
        'is_taxonomy' => 0,
      ),
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '89',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_min_variation_price' => '89',
    '_max_variation_price' => '89',
    '_default_attributes' => 
    array (
    ),
    '_min_variation_regular_price' => '89',
    '_max_variation_regular_price' => '89',
    'total_sales' => '7',
    '_edit_lock' => '1503552153:172',
    '_min_price_variation_id' => '90',
    '_max_price_variation_id' => '90',
    '_min_regular_price_variation_id' => '90',
    '_max_regular_price_variation_id' => '90',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_product_image_gallery' => '93',
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/Parkajacket1-400x400.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'variable',
    'product_cat' => 'jacket',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/Parkajacket1-400x400.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 94,
  'post_date' => '2012-02-23 22:39:44',
  'post_date_gmt' => '2012-02-23 22:39:44',
  'post_content' => 'Ut eleifend rhoncus augue sit amet dignissim. In mattis lobortis imperdiet. Aliquam molestie nisi et purus mattis volutpat. Cras dignissim, arcu vel pretium interdum, turpis sapien rutrum felis, non condimentum nulla orci ornare tellus.',
  'post_title' => 'Parka',
  'post_excerpt' => '',
  'post_name' => 'parka',
  'post_modified' => '2017-08-24 05:24:43',
  'post_modified_gmt' => '2017-08-24 05:24:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/shopdock/?post_type=product&#038;p=94',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_thumbnail_id' => '95',
    '_edit_last' => '172',
    '_regular_price' => '169',
    '_tax_status' => 'taxable',
    '_stock_status' => 'instock',
    '_visibility' => 'visible',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_price' => '169',
    '_stock' => NULL,
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    'total_sales' => '1',
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_edit_lock' => '1503552153:172',
    '_sold_individually' => 'no',
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/minshop/files/2012/02/parkajacket3-400x400.jpg',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'jacket',
  ),
  'thumb' => 'https://themify.me/demo/themes/minshop/files/2012/02/parkajacket3-400x400.jpg',
);
themify_process_post_import( $post );


$post = array (
  'ID' => 177,
  'post_date' => '2012-04-16 04:37:45',
  'post_date_gmt' => '2012-04-16 04:37:45',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '177',
  'post_modified' => '2012-04-16 04:37:45',
  'post_modified_gmt' => '2012-04-16 04:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?p=177',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '6',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 98,
  'post_date' => '2012-04-12 23:59:54',
  'post_date_gmt' => '2012-04-12 23:59:54',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '98',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/98/',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '6',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 178,
  'post_date' => '2012-04-16 04:37:45',
  'post_date_gmt' => '2012-04-16 04:37:45',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '178',
  'post_modified' => '2012-04-16 04:37:45',
  'post_modified_gmt' => '2012-04-16 04:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?p=178',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '121',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 97,
  'post_date' => '2012-04-12 23:59:54',
  'post_date_gmt' => '2012-04-12 23:59:54',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '97',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/97/',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '98',
    '_menu_item_object_id' => '7',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 96,
  'post_date' => '2012-04-12 23:59:54',
  'post_date_gmt' => '2012-04-12 23:59:54',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '96',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/96/',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '98',
    '_menu_item_object_id' => '8',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 179,
  'post_date' => '2012-04-16 04:37:45',
  'post_date_gmt' => '2012-04-16 04:37:45',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '179',
  'post_modified' => '2012-04-16 04:37:45',
  'post_modified_gmt' => '2012-04-16 04:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?p=179',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '8',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 154,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '154',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/154/',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '121',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 180,
  'post_date' => '2012-04-16 04:37:45',
  'post_date_gmt' => '2012-04-16 04:37:45',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '180',
  'post_modified' => '2012-04-16 04:37:45',
  'post_modified_gmt' => '2012-04-16 04:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?p=180',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '139',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 155,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '155',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 121,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/155/',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '154',
    '_menu_item_object_id' => '128',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 181,
  'post_date' => '2012-04-16 04:37:45',
  'post_date_gmt' => '2012-04-16 04:37:45',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '181',
  'post_modified' => '2012-04-16 04:37:45',
  'post_modified_gmt' => '2012-04-16 04:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?p=181',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '6',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 182,
  'post_date' => '2012-04-16 04:37:45',
  'post_date_gmt' => '2012-04-16 04:37:45',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '182',
  'post_modified' => '2012-04-16 04:37:45',
  'post_modified_gmt' => '2012-04-16 04:37:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/?p=182',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '152',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 156,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '156',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 121,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/156/',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '154',
    '_menu_item_object_id' => '126',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 157,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '157',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 121,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/157/',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '154',
    '_menu_item_object_id' => '123',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 158,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '158',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/158/',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '139',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 159,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '159',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 139,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/159/',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '158',
    '_menu_item_object_id' => '146',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );


$post = array (
  'ID' => 160,
  'post_date' => '2012-04-12 23:59:55',
  'post_date_gmt' => '2012-04-12 23:59:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '160',
  'post_modified' => '2015-01-26 21:26:39',
  'post_modified_gmt' => '2015-01-26 21:26:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minshop/2012/04/12/160/',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '152',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);
themify_process_post_import( $post );



function themify_import_get_term_id_from_slug( $slug ) {
	$menu = get_term_by( "slug", $slug, "nav_menu" );
	return is_wp_error( $menu ) ? 0 : (int) $menu->term_id;
}

	$widgets = get_option( "widget_woocommerce_price_filter" );
$widgets[1002] = array (
  'title' => 'Filter by price',
);
update_option( "widget_woocommerce_price_filter", $widgets );

$widgets = get_option( "widget_themify-feature-posts" );
$widgets[1003] = array (
  'title' => 'Recent Posts',
  'category' => '0',
  'show_count' => '3',
  'show_date' => 'on',
  'show_thumb' => 'on',
  'display' => 'none',
  'hide_title' => NULL,
  'thumb_width' => '50',
  'thumb_height' => '50',
  'excerpt_length' => '55',
  'orderby' => 'date',
  'order' => 'DESC',
);
update_option( "widget_themify-feature-posts", $widgets );

$widgets = get_option( "widget_themify-twitter" );
$widgets[1004] = array (
  'title' => 'Latest Tweets',
  'username' => 'themify',
  'show_count' => '3',
  'hide_timestamp' => NULL,
  'show_follow' => NULL,
  'follow_text' => '→ Follow me',
  'include_retweets' => 'on',
  'exclude_replies' => NULL,
);
update_option( "widget_themify-twitter", $widgets );

$widgets = get_option( "widget_text" );
$widgets[1005] = array (
  'title' => '',
  'text' => '<a href="https://themify.me"><img src="https://themify.me/wp-content/icons/banner-468x60.gif" alt="" /></a>',
  'filter' => false,
);
update_option( "widget_text", $widgets );

$widgets = get_option( "widget_themify-social-links" );
$widgets[1006] = array (
  'title' => '',
  'show_link_name' => NULL,
  'open_new_window' => NULL,
  'icon_size' => 'icon-medium',
  'orientation' => 'horizontal',
);
update_option( "widget_themify-social-links", $widgets );



$sidebars_widgets = array (
  'sidebar-main' => 
  array (
    0 => 'woocommerce_price_filter-1002',
    1 => 'themify-feature-posts-1003',
    2 => 'themify-twitter-1004',
  ),
  'header-widget' => 
  array (
    0 => 'text-1005',
  ),
  'social-widget' => 
  array (
    0 => 'themify-social-links-1006',
  ),
); 
update_option( "sidebars_widgets", $sidebars_widgets );

$menu_locations = array();
$menu = get_terms( "nav_menu", array( "slug" => "main-nav" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["main-nav"] = $menu[0]->term_id;
$menu = get_terms( "nav_menu", array( "slug" => "footer-nav" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["footer-nav"] = $menu[0]->term_id;
set_theme_mod( "nav_menu_locations", $menu_locations );


$homepage = get_posts( array( 'name' => 'shop', 'post_type' => 'page' ) );
			if( is_array( $homepage ) && ! empty( $homepage ) ) {
				update_option( 'show_on_front', 'page' );
				update_option( 'page_on_front', $homepage[0]->ID );
			}
			
	ob_start(); ?>a:62:{s:21:"setting-webfonts_list";s:11:"recommended";s:22:"setting-default_layout";s:8:"sidebar1";s:27:"setting-default_post_layout";s:9:"list-post";s:30:"setting-default_layout_display";s:7:"content";s:25:"setting-default_more_text";s:4:"More";s:21:"setting-index_orderby";s:4:"date";s:19:"setting-index_order";s:4:"DESC";s:31:"setting-image_post_feature_size";s:5:"blank";s:32:"setting-default_page_post_layout";s:8:"sidebar1";s:38:"setting-image_post_single_feature_size";s:5:"blank";s:27:"setting-default_page_layout";s:8:"sidebar1";s:53:"setting-customizer_responsive_design_tablet_landscape";s:4:"1024";s:43:"setting-customizer_responsive_design_tablet";s:3:"768";s:43:"setting-customizer_responsive_design_mobile";s:3:"480";s:33:"setting-mobile_menu_trigger_point";s:4:"1200";s:24:"setting-gallery_lightbox";s:8:"lightbox";s:26:"setting-page_builder_cache";s:2:"on";s:27:"setting-page_builder_expiry";s:1:"2";s:19:"setting-entries_nav";s:8:"numbered";s:26:"setting-feature_box_effect";s:5:"slide";s:25:"setting-feature_box_speed";s:4:"2000";s:24:"setting-feature_box_auto";s:1:"0";s:22:"setting-footer_widgets";s:17:"footerwidget-3col";s:19:"setting-shop_layout";s:8:"sidebar1";s:30:"setting-shop_products_per_page";s:1:"8";s:23:"setting-hide_shop_title";s:2:"on";s:29:"setting-single_product_layout";s:8:"sidebar1";s:30:"setting-related_products_limit";s:1:"3";s:27:"setting-shop_archive_layout";s:12:"sidebar-none";s:30:"setting-product_slider_enabled";s:2:"on";s:37:"setting-product_slider_posts_category";s:1:"0";s:30:"setting-product_slider_visible";s:1:"5";s:27:"setting-product_slider_auto";s:1:"0";s:29:"setting-product_slider_scroll";s:1:"1";s:28:"setting-product_slider_speed";s:3:"300";s:36:"setting-shop_search_option_preselect";s:4:"post";s:25:"setting-img_php_base_size";s:5:"large";s:27:"setting-global_feature_size";s:5:"large";s:22:"setting-link_icon_type";s:10:"image-icon";s:32:"setting-link_type_themify-link-0";s:10:"image-icon";s:33:"setting-link_title_themify-link-0";s:7:"Twitter";s:32:"setting-link_link_themify-link-0";s:26:"http://twitter.com/themify";s:31:"setting-link_img_themify-link-0";s:95:"https://themify.me/demo/themes/minshop/wp-content/themes/minshop/themify/img/social/twitter.png";s:32:"setting-link_type_themify-link-2";s:10:"image-icon";s:33:"setting-link_title_themify-link-2";s:7:"Google+";s:32:"setting-link_link_themify-link-2";s:45:"https://plus.google.com/102333925087069536501";s:31:"setting-link_img_themify-link-2";s:99:"https://themify.me/demo/themes/minshop/wp-content/themes/minshop/themify/img/social/google-plus.png";s:32:"setting-link_type_themify-link-1";s:10:"image-icon";s:33:"setting-link_title_themify-link-1";s:8:"Facebook";s:32:"setting-link_link_themify-link-1";s:27:"http://facebook.com/themify";s:31:"setting-link_img_themify-link-1";s:96:"https://themify.me/demo/themes/minshop/wp-content/themes/minshop/themify/img/social/facebook.png";s:32:"setting-link_type_themify-link-3";s:10:"image-icon";s:33:"setting-link_title_themify-link-3";s:7:"YouTube";s:31:"setting-link_img_themify-link-3";s:95:"https://themify.me/demo/themes/minshop/wp-content/themes/minshop/themify/img/social/youtube.png";s:32:"setting-link_type_themify-link-4";s:10:"image-icon";s:33:"setting-link_title_themify-link-4";s:9:"Pinterest";s:31:"setting-link_img_themify-link-4";s:97:"https://themify.me/demo/themes/minshop/wp-content/themes/minshop/themify/img/social/pinterest.png";s:22:"setting-link_field_ids";s:171:"{"themify-link-0":"themify-link-0","themify-link-2":"themify-link-2","themify-link-1":"themify-link-1","themify-link-3":"themify-link-3","themify-link-4":"themify-link-4"}";s:23:"setting-link_field_hash";s:1:"5";s:30:"setting-page_builder_is_active";s:6:"enable";s:46:"setting-page_builder_animation_parallax_scroll";s:6:"mobile";s:4:"skin";s:89:"https://themify.me/demo/themes/minshop/wp-content/themes/minshop/themify/img/non-skin.gif";}<?php $themify_data = unserialize( ob_get_clean() );

	// fix the weird way "skin" is saved
	if( isset( $themify_data['skin'] ) ) {
		$parsed_skin = parse_url( $themify_data['skin'], PHP_URL_PATH );
		$basedir_skin = basename( dirname( $parsed_skin ) );
		$themify_data['skin'] = trailingslashit( get_template_directory_uri() ) . 'skins/' . $basedir_skin . '/style.css';
	}

	themify_set_data( $themify_data );
	
}
themify_do_demo_import();